<?php
include_once("conexao.php");

if (!isset($_GET['paymentId'])) {
    header("Location: /");
    exit;
}

$paymentId = $_GET['paymentId'];

try {
    $stmt = $painel_geral->prepare("SELECT p.*, pl.nome as plano_nome 
                                   FROM pagamentos p
                                   JOIN planos pl ON p.dias = pl.dias AND p.CadUser = pl.CadUser
                                   WHERE p.paymentId = :paymentId");
    $stmt->bindParam(':paymentId', $paymentId, PDO::PARAM_STR);
    $stmt->execute();
    
    if ($stmt->rowCount() > 0) {
        $pagamento = $stmt->fetch(PDO::FETCH_ASSOC);
    } else {
        header("Location: /");
        exit;
    }
} catch (PDOException $e) {
    header("Location: /");
    exit;
}

?>
<!DOCTYPE html>
<html lang="pt-br">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1">
    <title>Obrigado por sua compra</title>
    <link href="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/css/bootstrap.min.css" rel="stylesheet">
    <link href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.4.0/css/all.min.css" rel="stylesheet">
    <style>
        body {
            font-family: 'Nunito', sans-serif;
            background-color: #f8f9fa;
        }
        .confirmation-card {
            border-radius: 15px;
            box-shadow: 0 0.5rem 1rem rgba(0, 0, 0, 0.15);
            border: none;
        }
        .confirmation-header {
            background-color: #28a745;
            color: white;
            border-radius: 15px 15px 0 0 !important;
        }
        .whatsapp-btn {
            background-color: #25D366;
            color: white;
        }
        .whatsapp-btn:hover {
            background-color: #128C7E;
            color: white;
        }
    </style>
</head>
<body>
    <div class="container py-5">
        <div class="row justify-content-center">
            <div class="col-lg-8">
                <div class="card confirmation-card">
                    <div class="card-header confirmation-header text-center py-4">
                        <h2><i class="fas fa-check-circle me-2"></i>Pagamento Confirmado!</h2>
                    </div>
                    <div class="card-body p-5">
                        <div class="text-center mb-4">
                            <i class="fas fa-check-circle text-success" style="font-size: 5rem;"></i>
                        </div>
                        
                        <h3 class="text-center mb-4">Obrigado por sua assinatura, <?= htmlspecialchars($pagamento['usuario']) ?>!</h3>
                        
                        <div class="row mb-4">
                            <div class="col-md-6 mb-3">
                                <div class="p-3 border rounded bg-light">
                                    <h5><i class="fas fa-box-open me-2"></i>Plano Contratado</h5>
                                    <p class="mb-0"><?= htmlspecialchars($pagamento['plano_nome']) ?></p>
                                </div>
                            </div>
                            <div class="col-md-6 mb-3">
                                <div class="p-3 border rounded bg-light">
                                    <h5><i class="fas fa-calendar-alt me-2"></i>Duração</h5>
                                    <p class="mb-0"><?= htmlspecialchars($pagamento['dias']) ?> dias</p>
                                </div>
                            </div>
                            <div class="col-md-6 mb-3">
                                <div class="p-3 border rounded bg-light">
                                    <h5><i class="fas fa-money-bill-wave me-2"></i>Valor Pago</h5>
                                    <p class="mb-0">R$ <?= number_format($pagamento['valor'], 2, ',', '.') ?></p>
                                </div>
                            </div>
                            <div class="col-md-6 mb-3">
                                <div class="p-3 border rounded bg-light">
                                    <h5><i class="fas fa-clock me-2"></i>Data do Pagamento</h5>
                                    <p class="mb-0"><?= date('d/m/Y H:i', strtotime($pagamento['datahora'])) ?></p>
                                </div>
                            </div>
                        </div>
                        
                        <div class="alert alert-info">
                            <h5><i class="fas fa-envelope me-2"></i>E-mail de Confirmação</h5>
                            <p class="mb-0">Enviamos os detalhes da sua assinatura para <strong><?= htmlspecialchars($pagamento['email']) ?></strong>.</p>
                            <?php if(!empty($pagamento['telefone'])): ?>
                                <p class="mt-2 mb-0">Caso não receba, verifique sua caixa de spam ou entre em contato conosco.</p>
                            <?php endif; ?>
                        </div>
                        
                        
                                
                                <?php if(!empty($pagamento['telefone'])): ?>
                                    <a href="https://wa.me/55<?= preg_replace('/[^0-9]/', '', $pagamento['telefone']) ?>?text=Olá,%20gostaria%20de%20ajuda%20com%20minha%20assinatura%20(ID:%20<?= $paymentId ?>)" 
                                       class="btn whatsapp-btn btn-lg px-5" target="_blank">
                                        <i class="fab fa-whatsapp me-2"></i>Suporte pelo WhatsApp
                                    </a>
                                <?php endif; ?>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        </div>
    </div>
    
    <script src="https://cdn.jsdelivr.net/npm/bootstrap@5.3.0/dist/js/bootstrap.bundle.min.js"></script>
    
    <!-- Removido o redirecionamento automático -->
</body>
</html>