<?php
// =============================================
// FUNÇÕES PARA QUERIES SEGURAS (USANDO PDO)
// =============================================

/**
 * Executa uma query SELECT de forma segura
 * @param string $sql Ex: "SELECT * FROM usuarios WHERE id = ?"
 * @param array $params Ex: [25]
 * @return array Resultados da consulta
 */
function selectSeguro($sql, $params = []) {
    global $painel_user, $painel_acessos, $painel_geral;
    
    // Define qual conexão usar (ajuste conforme sua necessidade)
    $pdo = $painel_user;
    
    try {
        $stmt = $pdo->prepare($sql);
        $stmt->execute($params);
        return $stmt->fetchAll(PDO::FETCH_ASSOC);
    } catch (PDOException $e) {
        error_log("Erro SQL: " . $e->getMessage());
        return [];
    }
}

/**
 * Executa INSERT/UPDATE/DELETE de forma segura
 * @param string $sql Ex: "UPDATE usuarios SET nome = ? WHERE id = ?"
 * @param array $params Ex: ['João', 25]
 * @return int Número de linhas afetadas
 */
function executaQuery($sql, $params = []) {
    global $painel_user;
    
    try {
        $stmt = $painel_user->prepare($sql);
        $stmt->execute($params);
        return $stmt->rowCount();
    } catch (PDOException $e) {
        error_log("Erro SQL: " . $e->getMessage());
        return 0;
    }
}