<?php
include_once("conexao.php");
require_once 'vendor/autoload.php';

header('Content-Type: application/json');

if (!isset($_GET['paymentId'])) {
    echo json_encode(['error' => 'Payment ID não fornecido']);
    exit;
}

$paymentId = $_GET['paymentId'];

try {
    // Primeiro verifica no banco de dados
    $stmt = $painel_geral->prepare("SELECT status, CadUser FROM pagamentos WHERE paymentId = :paymentId");
    $stmt->bindParam(':paymentId', $paymentId, PDO::PARAM_STR);
    $stmt->execute();
    
    if ($stmt->rowCount() > 0) {
        $pagamento = $stmt->fetch(PDO::FETCH_ASSOC);
        
        // Se já estiver aprovado no banco, retorna
        if ($pagamento['status'] == 'approved') {
            echo json_encode(['status' => 'approved']);
            exit;
        }
        
        // Se não, verifica no Mercado Pago
        $cadUser = $pagamento['CadUser'];
        
        // Busca credenciais MP
        $stmtMP = $painel_geral->prepare("SELECT clientid, clientsecret FROM contamercadopago WHERE CadUser = :cadUser");
        $stmtMP->bindParam(':cadUser', $cadUser, PDO::PARAM_STR);
        $stmtMP->execute();
        
        if ($stmtMP->rowCount() > 0) {
            $contaMP = $stmtMP->fetch(PDO::FETCH_ASSOC);
            MercadoPago\SDK::setClientId($contaMP['clientid']);
            MercadoPago\SDK::setClientSecret($contaMP['clientsecret']);
            
            $payment = MercadoPago\Payment::find_by_id($paymentId);
            
            // Atualiza status no banco de dados se mudou
            if ($payment->status != $pagamento['status']) {
                $stmtUpdate = $painel_geral->prepare("UPDATE pagamentos SET status = :status WHERE paymentId = :paymentId");
                $stmtUpdate->bindParam(':status', $payment->status, PDO::PARAM_STR);
                $stmtUpdate->bindParam(':paymentId', $paymentId, PDO::PARAM_STR);
                $stmtUpdate->execute();
            }
            
            echo json_encode(['status' => $payment->status]);
        } else {
            echo json_encode(['error' => 'Credenciais MP não encontradas']);
        }
    } else {
        echo json_encode(['error' => 'Pagamento não encontrado']);
    }
} catch (Exception $e) {
    echo json_encode(['error' => $e->getMessage()]);
}